@@ -11,6 +11,7 @@ from .circular_ensemble import CircularEnsemble
 from .plot_law import wigner_semicircular_law
 from .plot_law import marchenko_pastur_law
 from .plot_law import tracy_widom_law
+from .plot_law import manova_spectrum_distr
 
 from .tridiagonal_utils import tridiag_eigval_neg
 from .tridiagonal_utils import tridiag_eigval_hist
@@ -22,6 +23,7 @@ __all__ = ["GaussianEnsemble", "WishartEnsemble",
            "wigner_semicircular_law",
            "marchenko_pastur_law",
            "tracy_widom_law",
+           "manova_spectrum_distr",
            "tridiag_eigval_neg",
            "tridiag_eigval_hist",
            "householder_reduction"]
