@@ -24,9 +24,9 @@ def test_goe_init():
 
     assert goe.matrix.shape == (n_size,n_size)
 
-    assert_almost_equal(goe.matrix, np.array([[ 1.62434536, -0.84236252, 0.60832001],
-                                              [-0.84236252, 0.86540763, -1.5313728 ],
-                                              [ 0.60832001, -1.5313728, 0.3190391 ]]),
+    assert_almost_equal(goe.matrix, np.array([[ 2.29717124, -1.1912805 ,  0.8602944 ],
+                                              [-1.1912805 ,  1.22387121, -2.16568818],
+                                              [0.8602944 , -2.16568818,  0.45118942]]),
                         decimal=4)
 
 
@@ -155,12 +155,12 @@ def test_gue_init():
 
     assert gue.matrix.shape == (n_size,n_size)
 
-    mtx_sol = [[1.62434536+0.j, -0.84236252+0.89226257j,\
-                0.60832001-0.48012472j],
-               [-0.84236252-0.89226257j, 0.86540763+0.j,\
-                -1.5313728 +0.65309882j],
-               [0.60832001+0.48012472j, -1.5313728 -0.65309882j,\
-                0.3190391 +0.j]]
+    mtx_sol = [[2.29717124+0.j, -1.1912805+1.26184983j,\
+                0.8602944-0.67899889j],
+               [-1.1912805-1.26184983j, 1.22387121+0.j, \
+                -2.16568818+0.92362122j],
+               [0.8602944+0.67899889j, -2.16568818-0.92362122j,\
+                0.45118942+0.j]]
 
     assert_almost_equal(gue.matrix, np.array(mtx_sol),
                         decimal=4)
@@ -260,27 +260,27 @@ def test_gse_init():
 
     assert gse.matrix.shape == (2*n_size,2*n_size)
 
-    mtx_sol = [[1.62434536+0.86540763j, -0.56996408-0.27836347j,\
-                0.-0.3224172j, -0.85573916+0.37485754j],
-               [-0.56996408-0.27836347j, -1.07296862-0.7612069j,\
-                0.85573916+0.37485754j, 0.-1.09989127j],
-               [0.-0.3224172j, 0.85573916+0.37485754j,\
-                1.62434536-0.86540763j, -0.56996408+0.27836347j],
-               [-0.85573916+0.37485754j, 0.-1.09989127j, \
-                -0.56996408+0.27836347j, -1.07296862+0.7612069j]]
+    mtx_sol = [[2.29717124+0.j, -0.80605094-2.86120185j,\
+                0.+0.j, -1.21019792-1.0732635j],
+               [-0.80605094+2.86120185j, -1.51740678+0.j,\
+                1.21019792+1.0732635j, 0.+0.j],
+               [0.+0.j, 1.21019792-1.0732635j,\
+                2.29717124+0.j, -0.80605094+2.86120185j],
+               [-1.21019792+1.0732635j, 0.+0.j,\
+                -0.80605094-2.86120185j, -1.51740678+0.j]]
 
     assert_almost_equal(gse.matrix, np.array(mtx_sol),
                         decimal=4)
 
 
-def test_gse_symmetric():
-    '''Testing that GSE matrix is symmetric
+def test_gse_hermitian():
+    '''Testing that GSE matrix is hermitian
     '''
     n_size = 5
     gse = GaussianEnsemble(beta=4, n=n_size)
 
     m_tx = gse.matrix
-    assert (m_tx.transpose() == m_tx).all()
+    assert (m_tx.transpose().conj() == m_tx).all()
 
 
 def test_gse_set_size():
